from .sendfiles import returndata
from .sendfiles import uploadcsvfortraining
from .sendfiles import getpredictions

from .sendfiles import dolistkeys
from .sendfiles import dolistkeyswithkey
from .sendfiles import dodeletewithkey

from .sendfiles import getpicklezip
from .sendfiles import sendpicklezip
from .sendfiles import deploytoprod
from .sendfiles import nlp
from .sendfiles import nlpclassify
from .sendfiles import algoinfo

from .sendfiles import hyperpredictions
from .sendfiles import tcp_echo_client
from .sendfiles import retraining

from .callmas import dotraining
from .callmas import dopredictions



name = "maads"
